bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.broadcasting_multiplier
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.broadcasting_multiplier